TotalBytes

Trait TotalBytes 

pub trait TotalBytes {
    // Required method
    fn total_bytes(&self) -> usize;
}
The TotalBytes trait is used to determine how many bytes an object represents

This trait is used to determine how much time an object will take to be sent.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TotalBytes for i32

Source

impl TotalBytes for usize

Implementors