pub trait TotalBytes {
// Required method
fn total_bytes(&self) -> usize;
}Expand description
The TotalBytes trait is used to determine how many bytes an object
represents
This trait is used to determine how much time an object will take to be sent.
Required Methods
fn total_bytes(&self) -> usize
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".